[![Build Status](https://travis-ci.org/portfoliome/pgawedge.svg?branch=master)](https://travis-ci.com/portfoliome/pgawedge)
[![codecov.io](http://codecov.io/github/portfoliome/pgawedge/coverage.svg?branch=master)](http://codecov.io/github/portfoliome/pgawedge?branch=master)
[![Code Health](https://landscape.io/github/portfoliome/pgawedge/master/landscape.svg?style=flat)](https://landscape.io/github/portfoliome/pgawedge/master)

# pgawedge
Postgresql Sqlalchemy adapter.

# Purpose

pgawedge acts as an adapter(wedge) for setting sqlalchemy specifically to use postgres conventions, default postgres connection environmental variables, as well as contain helper utilities that typically arise for postgres. Many of the utilities rely on implementations buried throughout sqlalchemy's extensive documentation.

# Pre-release Status

NOTE: pgawedge is in a pre-release state and expect the API to change.
